@@ -1,16 +1,11 @@
 from .babel.views import LocaleView
 from .security.manager import SecurityManager
-from .security.views import AuthDBView, AuthOIDView, ResetMyPasswordView, \
-    ResetPasswordView, UserDBGeneralView, UserOIDGeneralView, RoleGeneralView, \
-    PermissionViewGeneralView, ViewMenuGeneralView, PermissionGeneralView
     
 from .views import IndexView
 from filters import TemplateFilters
 from flask import Blueprint
 from flask.ext.babel import Babel, gettext as _gettext, lazy_gettext
 from flask.ext.appbuilder.babel.manager import BabelManager
-from flask.ext.login import LoginManager
-from flask.ext.openid import OpenID
 from menu import Menu
 import os
 
@@ -83,19 +78,7 @@ class BaseApp():
         # Creating Developer's models
         self.db.create_all()
     
-        # 
-        lm = LoginManager()
-        lm.init_app(app)
-        lm.login_view = 'login'
-        oid = OpenID(app)
-        
-        self.sm = SecurityManager(db.session, 
-                            self._get_auth_type(), 
-                            self._get_role_admin(), 
-                            self._get_role_public(), 
-                            lm, 
-                            oid)
-        
+        self.sm = SecurityManager(app, db.session)
         self.babelmanager = BabelManager(app)
         
         self.app.before_request(self.sm.before_request)
@@ -123,29 +106,8 @@ class BaseApp():
         else:
             self.languages = {
                 'en': {'flag':'gb', 'name':'English'},
-                'pt': {'flag':'pt', 'name':'Portugal'}
                 }
     
-    def _get_auth_type(self):
-        if 'AUTH_TYPE' in self.app.config:
-            return self.app.config['AUTH_TYPE']
-        else:
-            return AUTH_DB
-      
-    
-    def _get_role_admin(self):
-        if 'AUTH_ROLE_ADMIN' in self.app.config:
-            return self.app.config['AUTH_ROLE_ADMIN']
-        else:
-            return 'Admin'
-      
-    def _get_role_public(self):
-        if 'AUTH_ROLE_PUBLIC' in self.app.config:
-            return self.app.config['AUTH_ROLE_PUBLIC']
-        else:
-            return 'Public'
-      
-    
     def _add_global_filters(self):
         self.template_filters = TemplateFilters(self.app, self.sm)
 
@@ -157,29 +119,7 @@ class BaseApp():
     def _add_admin_views(self):
         self.add_view_no_menu(self.indexview())
         self.add_view_no_menu(LocaleView())
-            
-        self.add_view_no_menu(ResetPasswordView())
-        self.add_view_no_menu(ResetMyPasswordView())
-
-        if self._get_auth_type() == AUTH_DB:
-            user_view = self._init_view_session(UserDBGeneralView)
-            auth_view = AuthDBView()
-        else:
-            user_view = self._init_view_session(UserOIDGeneralView)
-            auth_view = AuthOIDView()
-            self.sm.oid.after_login_func = auth_view.after_login
-        
-        self.add_view_no_menu(auth_view)
-        
-        self.add_view(user_view, "List Users"
-                                        ,"/users/list","user",
-                                        "Security")
-                                        
-        self.add_view(self._init_view_session(RoleGeneralView), "List Roles","/roles/list","tags","Security")
-        self.menu.add_separator("Security")
-        self.add_view(self._init_view_session(PermissionViewGeneralView), "Base Permissions","/permissions/list","lock","Security")
-        self.add_view(self._init_view_session(ViewMenuGeneralView), "Views/Menus","/viewmenus/list","list-alt","Security")
-        self.add_view(self._init_view_session(PermissionGeneralView), "Permission on Views/Menus","/permissionviews/list","lock","Security")
+        self.sm.register_views(self)
 
     def _init_view_session(self, baseview_class):
         if baseview_class.datamodel.session == None:
