@@ -1,13 +1,25 @@
 from flask import current_app, g, request, current_app
 from flask.ext.appbuilder import Base
 from flask.ext.login import current_user
-from models import User, Role, PermissionView, Permission, ViewMenu, \
-    assoc_permissionview_role
 from sqlalchemy import MetaData, Table
 from sqlalchemy.engine.reflection import Inspector
 from sqlalchemy.ext.declarative import declarative_base
 from werkzeug.security import generate_password_hash, check_password_hash
+from flask.ext.login import LoginManager
+from flask.ext.openid import OpenID
 
+from models import User, Role, PermissionView, Permission, ViewMenu, \
+    assoc_permissionview_role
+from views import AuthDBView, AuthOIDView, ResetMyPasswordView, \
+    ResetPasswordView, UserDBGeneralView, UserOIDGeneralView, RoleGeneralView, \
+    PermissionViewGeneralView, ViewMenuGeneralView, PermissionGeneralView
+
+
+
+
+AUTH_OID = 0
+AUTH_DB = 1
+AUTH_LDAP = 2
 
 
 class SecurityManager(object):
@@ -19,32 +31,49 @@ class SecurityManager(object):
     lm = None
     oid = None
 
-    def __init__(self, session, auth_type, auth_role_admin, auth_role_public, lm, oid = None):
+    def __init__(self, app, session):
         """
             SecurityManager contructor
+            param app:
+                The Flask app object
             param session:
                 the database session for security tables, passed to BaseApp
-            param auth_type:
-                the type of authentication to be used
-            param auth_role_admin:
-                the name of the Admin role: default 'Admin'
-            param auth_role_public:
-                the name of the Public role: default 'Public', this is the role for non
-                authenticated users
-            param lm:
-                The LoginManager initialized flask-Login
-            param oid:
-                optional, The flask-openId
         """
         self.session = session
-        self.auth_type = auth_type
-        self.auth_role_admin = auth_role_admin
-        self.auth_role_public = auth_role_public
+        self.auth_type = self._get_auth_type(app)
+        self.auth_role_admin = self._get_auth_role_admin(app)
+        self.auth_role_public = self._get_auth_role_public(app)
                     
-        self.lm = lm
-        self.oid = oid
+        self.lm = LoginManager(app)
+        self.lm.login_view = 'login'
+        self.oid = OpenID(app)
         self.lm.user_loader(self.load_user)        
         self.init_db()
+
+    def register_views(self, baseapp):
+        baseapp.add_view_no_menu(ResetPasswordView())
+        baseapp.add_view_no_menu(ResetMyPasswordView())
+
+        if self._get_auth_type(baseapp.app) == AUTH_DB:
+            user_view = baseapp._init_view_session(UserDBGeneralView)
+            auth_view = AuthDBView()
+        else:
+            user_view = baseapp._init_view_session(UserOIDGeneralView)
+            auth_view = AuthOIDView()
+            self.oid.after_login_func = auth_view.after_login
+        
+        baseapp.add_view_no_menu(auth_view)
+        
+        baseapp.add_view(user_view, "List Users"
+                                        ,"/users/list","user",
+                                        "Security")
+                                        
+        baseapp.add_view(baseapp._init_view_session(RoleGeneralView), "List Roles","/roles/list","tags","Security")
+        baseapp.menu.add_separator("Security")
+        baseapp.add_view(baseapp._init_view_session(PermissionViewGeneralView), "Base Permissions","/permissions/list","lock","Security")
+        baseapp.add_view(baseapp._init_view_session(ViewMenuGeneralView), "Views/Menus","/viewmenus/list","list-alt","Security")
+        baseapp.add_view(baseapp._init_view_session(PermissionGeneralView), "Permission on Views/Menus","/permissionviews/list","lock","Security")
+
         
     def load_user(self, pk):
         return self.get_user_by_id(int(pk))
@@ -169,16 +198,29 @@ class SecurityManager(object):
     def get_user_by_id(self, pk):
         return self.session.query(User).get(pk)
   
-    def _get_role_public(self):
+  
+    def _get_auth_type(self, app):
+        if 'AUTH_TYPE' in app.config:
+            return app.config['AUTH_TYPE']
+        else:
+            return AUTH_DB
+      
+    def _get_auth_role_admin(self, app):
+        if 'AUTH_ROLE_ADMIN' in app.config:
+            return app.config['AUTH_ROLE_ADMIN']
+        else:
+            return 'Admin'
+      
+    def _get_auth_role_public(self, app):
         """
             To retrive the name of the public role
-            used in a transaction
         """
-        if 'AUTH_ROLE_PUBLIC' in current_app.config:
-            return current_app.config['AUTH_ROLE_PUBLIC']
+        if 'AUTH_ROLE_PUBLIC' in app.config:
+            return app.config['AUTH_ROLE_PUBLIC']
         else:
             return 'Public'
   
+    
     def is_menu_public(self, item):
         """
             Check if menu item has public permissions
@@ -186,7 +228,7 @@ class SecurityManager(object):
             param item:
                 menu item
         """
-        role = self.session.query(Role).filter_by(name = self._get_role_public()).first()
+        role = self.session.query(Role).filter_by(name = self.auth_role_public).first()
         lst = role.permissions
         if lst:
             for i in lst:
@@ -205,7 +247,7 @@ class SecurityManager(object):
                 the name of the class view (child of BaseView)
         """
 
-        role = self.session.query(Role).filter_by(name = self._get_role_public()).first()
+        role = self.session.query(Role).filter_by(name = self.auth_role_public).first()
         lst = role.permissions
         if lst:
             for i in lst:
